# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.ai.cogneed.api.audio.recorder import recorder_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_recorder_dot_recorder__pb2
from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2


class RecordServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Record = channel.unary_unary(
        '/ai.cogneed.api.audio.recorder.RecordService/Record',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_recorder_dot_recorder__pb2.RecordRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )
    self.Consolidate = channel.unary_unary(
        '/ai.cogneed.api.audio.recorder.RecordService/Consolidate',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_recorder_dot_recorder__pb2.ConsolidateRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )


class RecordServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Record(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Consolidate(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_RecordServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Record': grpc.unary_unary_rpc_method_handler(
          servicer.Record,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_recorder_dot_recorder__pb2.RecordRequest.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
      'Consolidate': grpc.unary_unary_rpc_method_handler(
          servicer.Consolidate,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_recorder_dot_recorder__pb2.ConsolidateRequest.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.audio.recorder.RecordService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
